@@ -1,17 +1,14 @@
 package Map::Tube::Prague;
 
-# Pragmas.
 use strict;
 use warnings;
 use 5.006;
 
-# Modules.
 use File::Share ':all';
 use Moo;
 use namespace::clean;
 
-# Version.
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 # Get XML.
 has xml => (
@@ -118,11 +115,9 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Prague;
 
@@ -140,11 +135,9 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::Prague;
 
  # Object.
@@ -161,11 +154,9 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE3
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::GraphViz;
  use Map::Tube::GraphViz::Utils qw(node_color_without_label);
  use Map::Tube::Prague;
@@ -190,19 +181,17 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Prague/master/images/ex3.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Prague/master/images/ex3.png" alt="Pražské metro" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Prague/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Prague/master/images/ex3.png" alt="Pražské metro" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::Prague;
 
  # Object.
@@ -221,11 +210,9 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
 =head1 EXAMPLE5
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(encode_utf8);
  use Map::Tube::Prague;
 
@@ -297,7 +284,7 @@ Install the Map::Tube concrete metro modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Map-Tube-Prague>
+L<https://github.com/michal-josef-spacek/Map-Tube-Prague>
 
 =head1 AUTHOR
 
@@ -315,6 +302,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
